var actionModule = angular.module('action', ['i18n']);

actionModule.config(function($sceDelegateProvider) {
    // we need to normalize the URL as angular uses normalized URLs to check against the whitelist
    var urlParsingNode = document.createElement('a');
    urlParsingNode.setAttribute('href', ManagersContext.proxyServletUrl);
    var normalizedProxyServletUrl = urlParsingNode.href;

   $sceDelegateProvider.resourceUrlWhitelist([
     // Allow same origin resource loads.
     'self',
     // Allow loading from our assets domain.  Notice the difference between * and **.
           normalizedProxyServletUrl + '**'
   ]);

 });

actionModule.directive("action", function () {
    return {
        restrict: "E",
        scope: {
            ref: '=',
            parentList: '=',
            parentIndex: '=',
            types: '='
        },
        templateUrl: ManagersContext.localTemplatesPath + "/action.html",

        controller: function ($scope, i18nService) {

            $scope.updateTemplate = function() {
                if( Object.prototype.toString.call( $scope.ref ) === '[object Array]' ) {
                    $scope.actionTemplateUrl = ManagersContext.localTemplatesPath + "/actionsList.html";
                } else if ($scope.ref && $scope.ref.type != "empty") {
                    $scope.actionType = $scope.getActionType($scope.ref);
                    if ($scope.actionType != null) {
                        $scope.actionTemplateUrl = ManagersContext.localTemplatesPath + "/actions/"+$scope.actionType.id+".html";
                    }
                }
            };

            $scope.getActionType = function (action) {
                for (var i = 0; i < $scope.types.length; i++) {
                    var actionType = $scope.types[i];
                    if (actionType.id == action.type) {
                        return actionType;
                    }
                }
                return null;
            };

            $scope.addAction = function() {
                var actionType = $scope.added.addedActionType;
                $scope.added.addedActionType = null;
                var newAction = {
                    "type" : actionType.id,
                    "parameterValues" : {}
                };
                for (var i=0; i < actionType.parameters.length; i++) {
                    var parameter = actionType.parameters[i];
                    if (parameter.multivalued) {
                        if (parameter.defaultValue !== undefined && parameter.defaultValue != null && parameter.defaultValue.length > 0) {
                            newAction.parameterValues[parameter.id] = parameter.defaultValue.split(",");
                        } else {
                            newAction.parameterValues[parameter.id] = [];
                        }
                    } else {
                        if (parameter.defaultValue !== undefined && parameter.defaultValue != null && parameter.defaultValue.length > 0) {
                            newAction.parameterValues[parameter.id] = parameter.defaultValue;
                        } else {
                            if (parameter.type == "string") {
                                newAction.parameterValues[parameter.id] = "";
                            } else {
                                newAction.parameterValues[parameter.id] = null;
                            }
                        }
                    }
                }
                $scope.ref.push(newAction);
            };

            $scope.onRemove = function (index) {
                console.log("actions.js : onRemove("+ index +") called");
                $scope.parentList.splice(index, 1);
            };

            if (!$scope.ref) {
                console.log("actions.js: no action passed, creating empty one.");
                $scope.ref = {};
                $scope.ref.type = "empty";
            }

            console.log("actions.js: Initializing action controller for action " + $scope.ref + " of type="+$scope.ref.type + " parentIndex=" + $scope.parentIndex);

            $scope.added = {};
            $scope.updateTemplate();

            $scope.$watch("ref", function (newValue, oldValue) {
                console.log("actions.js : action changed, refreshing...");
                $scope.updateTemplate();
            });

            $scope.$watch("types.length", function (newValue, oldValue) {
                console.log("actions.js : action type list changed, refreshing...");
                $scope.updateTemplate();
            });
        }
    };
});